@@ -15,12 +15,12 @@ test_that("estimatePSCS()", {
   
   # this soil has a clay decrease then a clay increase and an argillic horizon
   # the argillic horizon ends at a bedrock contact
-  e <- estimatePSCS(p, attr='prop', hzdesgn='name')
+  e <- estimatePSCS(p, clay.attr='prop', texcl.attr="texture", hzdesgn='name')
   expect_equivalent(e, c(49, 89))
   
   # this soil does not have an argillic, so it is 25-100 but has 5cm thick O horizon
   # and is moderately deep to bedrock contact
-  g <- estimatePSCS(q, attr='prop', hzdesgn='name')
+  g <- estimatePSCS(q, clay.attr='prop', texcl.attr="texture", hzdesgn='name')
   expect_equivalent(g, c(30, 59))
   
 })
